@@ -330,7 +330,7 @@ class DiggHomePlugin(hildondesktop.HomePluginItem):
             if list != None:
                 for item in list:
                     button = DiggItemWidget(item)
-                    self.vbox.add(button)
+                    self.vbox.pack_start(button, False)
             self.show_all()
             self.client.set_string(CATGR, self.category)
             title = self.category
